"use strict";
var path = require('path');
var SimpleApi = (function () {
    function SimpleApi(url, debug) {
        if (debug === void 0) { debug = false; }
        this.callback = {};
        this.debugLog = console.log;
        this.baseUrl = url;
        this.debug(debug);
    }
    SimpleApi.prototype.debug = function (d) {
        if (d) {
            this.debugLog = console.log;
        }
        else {
            this.debugLog = function () { };
        }
    };
    SimpleApi.prototype.list = function () {
        return Object.keys(this.callback);
    };
    SimpleApi.prototype.register = function (p, cb) {
        var apiPath = path.normalize(path.join(this.baseUrl, p));
        if (this.callback[apiPath]) {
            this.debugLog('SimpleApi.register: ' + apiPath + ' already register.');
            return false;
        }
        else {
            this.callback[apiPath] = cb;
            this.debugLog('SimpleApi.register: ' + apiPath);
            return true;
        }
    };
    SimpleApi.prototype.registerObject = function (obj) {
        var _this = this;
        this.debugLog('SimpleApi.registerObject: ' + this.baseUrl + ' - Start');
        Object.keys(obj).forEach(function (i) { return _this.register(i, obj[i]); });
        this.debugLog('SimpleApi.registerObject: ' + this.baseUrl + ' - End');
    };
    SimpleApi.prototype.unregister = function (p) { };
    SimpleApi.prototype.unregisterObj = function (obj) { };
    SimpleApi.prototype.handler = function (req) {
        if (this.callback[req.url]) {
            try {
                this.debugLog('SimpleApi.handler callback params: ' + JSON.stringify(req.body.params, null, 2));
                var result = { result: this.callback[req.url](req.body.params, req.params) };
                this.debugLog('SimpleApi.handler callback result: ' + JSON.stringify(result, null, 2));
                return result;
            }
            catch (e) {
                var error = { error: e };
                this.debugLog('SimpleApi.handler callback error: ' + JSON.stringify(error, null, 2));
                return error;
            }
        }
        else {
            var error = { status: 404, error: req.url + ' not found' };
            this.debugLog('SimpleApi.handler throw error: ' + JSON.stringify(error, null, 2));
            throw error;
        }
    };
    SimpleApi.prototype.response = function (req, res) {
        try {
            this.debugLog('SimpleApi.response callback params: ' + JSON.stringify(req.body.params, null, 2));
            res.json(this.handler(req));
        }
        catch (e) {
            res.status(e.status).end(e.error);
        }
    };
    return SimpleApi;
}());
exports.SimpleApi = SimpleApi;
;
//# sourceMappingURL=simple-api.js.map